@@ -107,6 +107,9 @@ See [API.md](./API.md).
 
 This project is licensed under the Apache-2.0 License.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
